<?php
/**
 * Summary Main Oxygen class to include more files, load translations and add settings link in plugin list.
 *
 * @package Oxygen
 * Oxygen MyData Class File
 *
 * @version 1.0.0
 * @since  1.0.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Oxygen MyData Class
 */
class Oxygen {



	/**
	 * Singleton Instance of Oxygen
	 *
	 * @var Oxygen
	 **/
	private static $instance = null;


	/**
	 * Singleton init Function
	 *
	 * @static
	 */
	public static function init() {
		if ( ! self::$instance ) {
			self::$instance = new self();

		}
		return self::$instance;
	}

	/**
	 * Oxygen Constructor
	 */
	private function __construct() {

		$this->init_hooks();
	}

	/**
	 *  Requires files and hooks translations and settings link
	 *
	 *  @return void
	 */
	private function init_hooks() {

		require_once OXYGEN_PLUGIN_DIR . '/inc/class-oxygenwoosettings.php';
		OxygenWooSettings::init();

		require_once OXYGEN_PLUGIN_DIR . '/inc/class-oxygenorder.php';
		OxygenOrder::init();

		require_once OXYGEN_PLUGIN_DIR . '/inc/class-oxygenapi.php';
		OxygenApi::init();

		add_action( 'init', array( $this, 'load_text_domain' ), 100 );
		add_filter( 'plugin_action_links_' . OXYGEN_PLUGIN_BASENAME, array( $this, 'add_plugin_page_settings_link' ) );

	}

	/**
	 * Loads Translations
	 */
	public static function load_text_domain() {
		load_plugin_textdomain( 'oxygen', false, dirname( plugin_basename( OXYGEN_PLUGIN_FILE ) ) . '/languages' );
	}

	/**
	 *  Adds plugins list settings link
	 *
	 *  @param Array $links array of existing plugins links.
	 *
	 *  @return Array
	 */
	public static function add_plugin_page_settings_link( $links ) {
		$newlinks[] = '<a href="' .
			admin_url( 'admin.php?page=wc-settings&tab=oxygen' ) .
			'">' . __( 'Settings' ) . '</a>';
		return array_merge( $newlinks, $links );
	}

}
